==> app-model-2.0.1-sources.jar: com/bxm/app/model/dto/AppEntranceAdDto.java <==
package com.bxm.app.model.dto;

import io.swagger.annotations.ApiModelProperty;

public class AppEntranceAdDto {

    /**
     * 主键id
     */
    @ApiModelProperty(value = "id")
    private Long   id;

    /**
     * 备注
     */
    @ApiModelProperty(value = "备注")
    private String remark;

    /**
     * 别名
     */
    @ApiModelProperty(value = "别名")
    private String alias;

    /**
     * 媒体分类
     */
    @ApiModelProperty(value = "媒体分类")
    private String  mediaClass;

    /**
     * 媒体子分类
     */
    @ApiModelProperty(value = "媒体子分类")
    private String  mediaChildClass;
    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return the remark
     */
    public String getRemark() {
        return remark;
    }

    /**
     * @param remark the remark to set
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }

    /**
     * @return the alias
     */
    public String getAlias() {
        return alias;
    }

    /**
     * @param alias the alias to set
     */
    public void setAlias(String alias) {
        this.alias = alias;
    }

    
    public String getMediaClass() {
        return mediaClass;
    }

    
    public void setMediaClass(String mediaClass) {
        this.mediaClass = mediaClass;
    }

    
    public String getMediaChildClass() {
        return mediaChildClass;
    }

    
    public void setMediaChildClass(String mediaChildClass) {
        this.mediaChildClass = mediaChildClass;
    }

}

==> app-model-2.0.12-sources.jar: com/bxm/app/model/dto/AppEntranceAdDto.java <==
package com.bxm.app.model.dto;

import io.swagger.annotations.ApiModelProperty;

public class AppEntranceAdDto {

    /**
     * 主键id
     */
    @ApiModelProperty(value = "id")
    private Long   id;

    /**
     * 备注
     */
    @ApiModelProperty(value = "备注")
    private String remark;

    /**
     * 别名
     */
    @ApiModelProperty(value = "别名")
    private String alias;

    /**
     * 媒体分类
     */
    @ApiModelProperty(value = "媒体分类")
    private String  mediaClass;

    /**
     * 媒体子分类
     */
    @ApiModelProperty(value = "媒体子分类")
    private String  mediaChildClass;

    // v.20180710-positionType新增字段
    @ApiModelProperty(value = "广告位类型, 信息流:INFORMATION_FLOW,非信息流:NON_INFORMATION_FLOW")
    private String positionType; // 广告位类型

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return the remark
     */
    public String getRemark() {
        return remark;
    }

    /**
     * @param remark the remark to set
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }

    /**
     * @return the alias
     */
    public String getAlias() {
        return alias;
    }

    /**
     * @param alias the alias to set
     */
    public void setAlias(String alias) {
        this.alias = alias;
    }

    
    public String getMediaClass() {
        return mediaClass;
    }

    
    public void setMediaClass(String mediaClass) {
        this.mediaClass = mediaClass;
    }

    
    public String getMediaChildClass() {
        return mediaChildClass;
    }

    
    public void setMediaChildClass(String mediaChildClass) {
        this.mediaChildClass = mediaChildClass;
    }

    public String getPositionType() {
        return positionType;
    }

    public void setPositionType(String positionType) {
        this.positionType = positionType;
    }
}
